"""
Fuctions for automatically finding and retrieving recent ClinVar VCF file.

Notes:
- 'build' is explicitly required by these functions to avoid potential
    accidental build mismatches during processing.
- The most recent file is stored with a filename constructed by concatenating
    the genome build with the ClinVar file's original name. Example: if the
    ClinVar filename is 'clinvar_20150330.vcf.gz' and the build is 'b37', then
    the locally stored file is named 'b37_clinvar_20150330.vcf.gz'.
"""
import os
import re
from ftplib import FTP

DIR_CLINVAR_VCF_B37 = 'pub/clinvar/vcf_GRCh37'
DIR_CLINVAR_VCF_B38 = 'pub/clinvar/vcf_GRCh38'


def nav_to_vcf_dir(ftp, build):
    """
    Navigate an open ftplib.FTP to appropriate directory for ClinVar VCF files.

    Args:
        ftp:   (type: ftplib.FTP) an open connection to ftp.ncbi.nlm.nih.gov
        build: (type: string) genome build, either 'b37' or 'b38'
    """
    if build == 'b37':
        ftp.cwd(DIR_CLINVAR_VCF_B37)
    elif build == 'b38':
        ftp.cwd(DIR_CLINVAR_VCF_B38)
    else:
        raise IOError("Genome build not recognized.")


def latest_vcf_filename(build):
    """
    Determine the filename for the most recent comprehensive ClinVar VCF.

    Args:
        build: (type: string) genome build, either 'b37' or 'b38'

    Returns:
        (type: string) Filename of the most recent comprehensive ClinVar VCF.
    """
    ftp = FTP('ftp.ncbi.nlm.nih.gov')
    ftp.login()
    nav_to_vcf_dir(ftp, build=build)
    clinvar_datestamped = [f for f in ftp.nlst() if
                           re.match('^clinvar_[0-9]{8}.vcf.gz$', f)]
    if len(clinvar_datestamped) == 1:
        return clinvar_datestamped[0]
    raise IOError("Unable to determine the most recent ClinVar VCF file on " +
                  "NCBI's FTP site.")


def get_latest_vcf_file(target_dir, build, overwrite=False):
    """
    Download most recent ClinVar VCF to target local dir, if not already there.

    Args:
        target_dir: (type: string) Relative path to target local directory
        build:      (type: string) genome build, either 'b37' or 'b38'
        overwrite:  (type: boolean; optional, default=False) Whether to
                    a local ClinVarFile that appears to be current based on the
                    filename.

    Returns:
        (type: string) Local path to the up-to-date comprehensive ClinVar VCF.
    """
    latest_filename = latest_vcf_filename(build)
    target_filename = os.path.join(target_dir, build + '_' + latest_filename)

    # Abort if we believe we already have this file and overwrite is False.
    if not overwrite and os.path.exists(target_filename):
        return target_filename

    # Get the file.
    with open(target_filename, 'wb') as fh:
        ftp = FTP('ftp.ncbi.nlm.nih.gov')
        ftp.login()
        nav_to_vcf_dir(ftp, build=build)
        ftp.retrbinary('RETR %s' % latest_filename, fh.write)

    return target_filename



#!/usr/bin/python
#

from __future__ import unicode_literals
from argparse import ArgumentParser
import bz2
import csv
import gzip
import json
import os
from signal import signal, SIGPIPE, SIGINT, SIG_DFL
import sys

from vcf2clinvar import match_to_clinvar
from vcf2clinvar.clinvar_update import get_latest_vcf_file

# Don't stack dump on keyboard ctrl-c or on premature
# termination of output stream (say from piping output
# through head).
#
signal(SIGPIPE, SIG_DFL)
signal(SIGINT, SIG_DFL)


def json_report(input_genome_file, input_clinvar_file, build, notes, version):
    json_report = {}
    json_report["vcf2clinvar-version"] = version
    json_report["notes"] = notes
    json_report["genome-build"] = build
    json_report["variants"] = []
    matching = match_to_clinvar(input_genome_file, input_clinvar_file)
    for genome_vcf_line, clinvar_allele, zygosity in matching:
        for record in clinvar_allele.records:
            data = {
                'chrom': genome_vcf_line.chrom,
                'pos': genome_vcf_line.start,
                'ref_allele': genome_vcf_line.ref_allele,
                # Note that var_allele CAN be the same as the ref_allele, if
                # the reference variant is considered pathogenic! Factor V
                # Leiden is a famous example.
                'alt_allele': clinvar_allele.sequence,
                'zygosity': zygosity,
                'name': record.dbn,
                'acc_url': 'http://www.ncbi.nlm.nih.gov/clinvar/' + record.acc,
                'allele_freq': clinvar_allele.frequency,
                'clinical_significance': record.inf,
            }
            json_report['variants'].append(data)
    print(json.dumps(json_report))


def csv_report(input_genome_file, input_clinvar_file, build, version):
    print('##genome-build=%s' % build)
    print('##vcf2clinvar-version=%s' % version)
    csv_out = csv.writer(sys.stdout, lineterminator=os.linesep)
    header = ('Chromosome', 'Position', 'Reference allele', 'Variant allele',
              'Name', 'Significance', 'Frequency', 'Zygosity',
              'ClinVar accession URL')
    csv_out.writerow(header)
    matching = match_to_clinvar(input_genome_file, input_clinvar_file)
    for genome_vcf_line, clinvar_allele, zygosity in matching:
        chrom = genome_vcf_line.chrom
        pos = genome_vcf_line.start
        ref_allele = genome_vcf_line.ref_allele
        alt_allele = clinvar_allele.sequence
        name = ':'.join([r.dbn for r in clinvar_allele.records])
        allele_freq = clinvar_allele.frequency
        zygosity = zygosity
        for record in clinvar_allele.records:
            name = record.dbn
            clnsig = record.sig
            url = url = 'http://www.ncbi.nlm.nih.gov/clinvar/' + record.acc
            data = (chrom, pos, ref_allele, alt_allele, name, clnsig,
                    allele_freq, zygosity, url)
            csv_out.writerow(data)


def main():
    """
    Parse command line argument and
    output appropriate file type (csv or JSON)
    """
    parser = ArgumentParser()

    parser.add_argument(
        "-c", "--clinvarfile", dest="clinvarfile",
        help="ClinVar VCF file (either this or -C must be specified)",
        metavar="CLINVARFILE")
    parser.add_argument(
        "-C", "--clinvardir", dest="clinvardir",
        help="ClinVar VCF directory (either this or -c must be specified). " +
        "This option will use vcf2clinvar.clinvar_update to automatically " +
        "check and import the most recent ClinVar file to this directory.",
        metavar="CLINVARDIR")
    parser.add_argument(
        "-i", "--input", dest="inputfile",
        help="Input VCF file ['.vcf', '.vcf.gz', '.vcf.bz2']. " +
        "Uncompressed genome data is also accepted via stdin.",
        metavar="INPUT")
    parser.add_argument(
        "-t", "--type", dest="type", default='csv',
        help="Output report type ('csv' or 'json'). Defaults to csv. " +
        "CSV Report: Reports all genome variants matching ClinVar records, " +
        "and some summary ClinVar data from these records. Header lines " +
        "with metadata begin with '##'.\n" +
        "JSON Report: Reports genome variants matching ClinVar records " +
        "(no record information is included).",
        metavar="TYPE")
    parser.add_argument(
        "-n", "--notes", dest="notes",
        help="Notes (JSON format) to include in report. (JSON report only)",
        metavar="NOTES")
    parser.add_argument(
        "-g", "--genome-build", dest="build",
        help="Genome build to include in report ('b37' or 'b38').",
        metavar="GENOMEBUILD")
    options = parser.parse_args()

    version = os.popen("python setup.py --version").read().strip()

    if options.inputfile:
        if options.inputfile.endswith('.vcf'):
            input_genome_file = open(options.inputfile)
        elif options.inputfile.endswith('.vcf.gz'):
            input_genome_file = gzip.open(options.inputfile)
        elif options.inputfile.endswith('.vcf.bz2'):
            input_genome_file = bz2.BZ2File(options.inputfile)
        else:
            raise IOError("Genome filename expected to end with ''.vcf'," +
                          " '.vcf.gz', or '.vcf.bz2'.")
    elif not sys.stdin.isatty():
        input_genome_file = sys.stdin
    else:
        sys.stderr.write("Provide input VCF file\n")
        parser.print_help()
        sys.exit(1)

    if options.build and options.build in ['b37', 'b38']:
        build = options.build
    else:
        raise IOError("Input VCF genome build must be 'b37' or 'b38'.")

    if (not (options.clinvarfile or options.clinvardir) or
            (options.clinvarfile and options.clinvardir)):
        sys.stderr.write("Please provide either a ClinVar file or directory.")
        parser.print_help()
        sys.exit(1)
    if options.clinvarfile:
        clinvarfilename = options.clinvarfile
    elif options.clinvardir:
        clinvarfilename = get_latest_vcf_file(target_dir=options.clinvardir,
                                              build=build)
    if clinvarfilename.endswith('.vcf'):
        input_clinvar_file = open(options.clinvarfile)
    elif clinvarfilename.endswith('.vcf.gz'):
        input_clinvar_file = gzip.open(clinvarfilename)
    elif clinvarfilename.endswith('.vcf.bz2'):
        input_clinvar_file = bz2.BZ2File(clinvarfilename)
    else:
        raise IOError("ClinVar filename expected to end with '.vcf'," +
                      " '.vcf.gz', or '.vcf.bz2'.")

    if options.type not in ['csv', 'json']:
        raise IOError("Not a valid report type, must be 'csv' or 'json'.")
    if options.type == "csv":
        csv_report(input_genome_file=input_genome_file,
                   input_clinvar_file=input_clinvar_file,
                   build=build,
                   version=version)
    elif options.type == "json":
        notes_json = {}
        if options.notes:
            notes_json["parameter"] = options.notes
            try:
                notes_json = json.loads(options.notes)
            except:
                sys.stderr.write("Could not parse JSON notes field\n")
        json_report(input_genome_file=input_genome_file,
                    input_clinvar_file=input_clinvar_file,
                    build=build,
                    notes=notes_json,
                    version=version)

if __name__ == "__main__":
    main()



from __future__ import unicode_literals
import re

from .common import VCFLine


class GenomeVCFLine(VCFLine):
    """Store Genome data from a VCF line."""
    def __init__(self, *args, **kwargs):
        super(GenomeVCFLine, self).__init__(self, *args, **kwargs)
        vcf_line = kwargs['vcf_line']
        vcf_fields = vcf_line.strip().split('\t')
        self.genotype_allele_indexes = self._parse_genotype(vcf_fields)
        self.filters = self._parse_filter(vcf_fields)

    def _parse_filter(self, vcf_fields):
        return vcf_fields[6].split(';')

    def _parse_genotype(self, vcf_fields):
        """Parse genotype from VCF line data"""
        format_col = vcf_fields[8].split(':')
        genome_data = vcf_fields[9].split(':')
        try:
            gt_idx = format_col.index('GT')
        except ValueError:
            return []
        return [int(x) for x in re.split(r'[\|/]', genome_data[gt_idx]) if
                x != '.']



from __future__ import unicode_literals
import json
import re


CHROM_INDEX = {
    '1': 1, '2': 2, '3': 3, '4': 4, '5': 5,
    '6': 6, '7': 7, '8': 8, '9': 9, '10': 10,
    '11': 11, '12': 12, '13': 13, '14': 14, '15': 15,
    '16': 16, '17': 17, '18': 18, '19': 19, '20': 20,
    '21': 21, '22': 22, 'X': 23, 'Y': 24, 'M': 25, 'MT': 25,
    'chr1': 1, 'chr2': 2, 'chr3': 3, 'chr4': 4, 'chr5': 5,
    'chr6': 6, 'chr7': 7, 'chr8': 8, 'chr9': 9, 'chr10': 10,
    'chr11': 11, 'chr12': 12, 'chr13': 13, 'chr14': 14, 'chr15': 15,
    'chr16': 16, 'chr17': 17, 'chr18': 18, 'chr19': 19, 'chr20': 20,
    'chr21': 21, 'chr22': 22, 'chrX': 23, 'chrY': 24, 'chrM': 25, 'chrMT': 25,
}

REV_CHROM_INDEX = {
    1: 'chr1', 2: 'chr2', 3: 'chr3', 4: 'chr4', 5: 'chr5',
    6: 'chr6', 7: 'chr7', 8: 'chr8', 9: 'chr9', 10: 'chr10',
    11: 'chr11', 12: 'chr12', 13: 'chr13', 14: 'chr14', 15: 'chr15',
    16: 'chr16', 17: 'chr17', 18: 'chr18', 19: 'chr19', 20: 'chr20',
    21: 'chr21', 22: 'chr22', 23: 'chrX', 24: 'chrY', 25: 'chrMT',
}


class Allele(object):
    """Store data relating to one allele.

    Instance attributes:
    sequence:  (string) The DNA sequence of this allele, may only contain the
               characters A, C, G, T, or N.
    frequency: (string) String representation of a number between 0 and 1,
               or "Unknown".
    """
    def __init__(self, *args, **kwargs):
        """
        Initialize Allele object

        Required arguments:
        sequence:  Short string of DNA letters (ACGT) for the allele.
                   May be empty (to represent a deletion).

        Optional arguments:
        frequency: a string representation of a float between 0 and 1
        """
        sequence = kwargs['sequence']
        if 'frequency' in kwargs:
            frequency = kwargs['frequency']
        else:
            frequency = 'Unknown'

        if not (re.match(r'^[ACGTN]*$', sequence) or
                re.match(r'^<.*>$', sequence)):
            raise ValueError("Allele sequence isn't a standard DNA sequence")
        self.sequence = sequence
        if frequency:
            try:
                if (float(frequency) < 0.0 or
                        float(frequency) > 1.0):
                    raise ValueError('Allele frequency not between 0 and 1')
            except ValueError:
                if not frequency == 'Unknown':
                    raise ValueError('Allele frequency must be a number ' +
                                     'between 0 and 1, or the string ' +
                                     '"Unknown".')
            self.frequency = frequency

    def __unicode__(self):
        """Print Allele object as dict object data."""
        return self.as_json()

    def __str__(self):
        """Print Allele object as dict object data."""
        return self.as_json()

    def as_dict(self):
        """Return Allele data as dict object."""
        self_as_dict = dict()
        self_as_dict['sequence'] = self.sequence
        if hasattr(self, 'frequency'):
            self_as_dict['frequency'] = self.frequency
        return self_as_dict

    def as_json(self):
        """Print Allele object as JSON."""
        return json.dumps(self.as_dict())


class VCFLine(object):
    """Process data from a VCF line."""

    def __init__(self, *args, **kwargs):
        """Store data from a VCF line."""
        vcf_line = kwargs['vcf_line']
        skip_info = ('skip_info' in kwargs and kwargs['skip_info'])

        vcf_fields = vcf_line.strip().split('\t')
        self.chrom = vcf_fields[0]
        self.start = int(vcf_fields[1])
        self.ref_allele = vcf_fields[3]
        if vcf_fields[4] == '.':
            self.alt_alleles = []
        else:
            self.alt_alleles = vcf_fields[4].split(',')
        if not skip_info:
            self.info = self._parse_info(vcf_fields[7])
        self.alleles = self._parse_allele_data()

    def _parse_allele_data(self):
        """Create list of Alleles from VCF line data"""
        return [Allele(sequence=x) for x in
                [self.ref_allele] + self.alt_alleles]

    def _parse_info(self, info_field):
        """Parse the VCF info field"""
        info = dict()
        for item in info_field.split(';'):
            # Info fields may be "foo=bar" or just "foo".
            # For the first case, store key "foo" with value "bar"
            # For the second case, store key "foo" with value True.
            info_item_data = item.split('=')
            # If length is one, just store as a key with value = true.
            if len(info_item_data) == 1:
                info[info_item_data[0]] = True
            elif len(info_item_data) == 2:
                info[info_item_data[0]] = info_item_data[1]
        return info

    def __str__(self):
        """String representation of parsed VCF data"""
        return json.dumps(self.as_dict(), ensure_ascii=True)

    def as_dict(self):
        """Dict representation of parsed VCF data"""
        self_as_dict = {'chrom': self.chrom,
                        'start': self.start,
                        'ref_allele': self.ref_allele,
                        'alt_alleles': self.alt_alleles,
                        'alleles': [x.as_dict() for x in self.alleles]}
        try:
            self_as_dict['info'] = self.info
        except AttributeError:
            pass
        return self_as_dict

    @staticmethod
    def get_pos(vcf_line):
        """
        Very lightweight parsing of a vcf line to get position.

        Returns a dict containing:
        'chrom': index of chromosome (int), indicates sort order
        'pos': position on chromosome (int)
        """
        if not vcf_line:
            return None
        vcf_data = vcf_line.strip().split('\t')
        return_data = dict()
        return_data['chrom'] = CHROM_INDEX[vcf_data[0]]
        return_data['pos'] = int(vcf_data[1])
        return return_data



from __future__ import unicode_literals

from collections import OrderedDict
import json

from .common import Allele, VCFLine


CLNSIG_INDEX = {
    '0': "unknown",
    '1': "untested",
    '2': "non-pathogenic",
    '3': "probably non-pathogenic",
    '4': "probably pathogenic",
    '5': "pathogenic",
    '6': "affecting drug response",
    '7': "affecting histocompatibility",
    '255': "other"}


class ClinVarAllele(Allele):
    """Store ClinVar data relating to one allele."""
    def __init__(self, *args, **kwargs):
        """
        Initialize ClinVarAllele object

        A ClinVarAllele is an allele for a genomic position that has data
        from ClinVar associated with it.

        Required arguments:
        sequence:  String of DNA letters (A, C, G, or T) for the allele;
                   may be empty (to represent a deletion)
        frequency: Preferred allele frequency
        alleleid:  ClinVar Allele ID
        clnhgvs:   HGVS nomenclature for this allele
        clnsig:    ClinVar clinical significance
        clndn:     ClinVar disease name
        clndisdb:  Database IDs of disease database entries (tag-value pairs)
        clnvi:     Database IDs of clinical sources (tag-value pairs)
        """
        (self.clnalleleid, self.hgvs, self.clnsig,
         self.clndn, self.clndisdb, self.clnvi) = [
            kwargs[x] for x in
            ['alleleid', 'clnhgvs', 'clnsig', 'clndn', 'clndisdb', 'clnvi']]
        super(ClinVarAllele, self).__init__(*args, **kwargs)

    def as_dict(self, *args, **kwargs):
        """Return ClinVarAllele data as dict object."""
        self_as_dict = super(ClinVarAllele, self).as_dict(*args, **kwargs)
        self_as_dict['hgvs'] = self.hgvs
        self_as_dict['clnalleleid'] = self.clnalleleid
        self_as_dict['clnsig'] = self.clnsig
        self_as_dict['clndn'] = self.clndn
        self_as_dict['clndisdb'] = self.clndisdb
        self_as_dict['clnvi'] = self.clnvi
        return self_as_dict


class ClinVarVCFLine(VCFLine):
    """Store ClinVar data from a VCF line."""

    def __init__(self, *args, **kwargs):
        """Initialize ClinVarVCFLine with VCF line"""
        kwargs['skip_info'] = False
        super(ClinVarVCFLine, self).__init__(self, *args, **kwargs)

    def as_dict(self):
        """Dict representation of parsed ClinVar VCF line"""
        return {'chrom': self.chrom,
                'start': self.start,
                'ref_allele': self.ref_allele,
                'alt_alleles': self.alt_alleles,
                'info': self.info,
                'alleles': [x.as_dict() for x in self.alleles]}

    def _parse_frequencies(self):
        """Parse frequency data in ClinVar VCF"""
        frequencies = OrderedDict([
            ('EXAC', 'Unknown'),
            ('ESP', 'Unknown'),
            ('TGP', 'Unknown')])
        pref_freq = 'Unknown'
        for source in frequencies.keys():
            freq_key = 'AF_' + source
            if freq_key in self.info:
                frequencies[source] = self.info[freq_key]
                if pref_freq == 'Unknown':
                    pref_freq = frequencies[source]
        return pref_freq, frequencies

    def _parse_allele_data(self):
        """Parse alleles for ClinVar VCF, overrides parent method."""

        # Get allele frequencies if they exist.
        pref_freq, frequencies = self._parse_frequencies()

        info_clnvar_single_tags = ['ALLELEID', 'CLNSIG', 'CLNHGVS']
        cln_data = {x.lower(): self.info[x] if x in self.info else None
                    for x in info_clnvar_single_tags}
        cln_data.update(
            {'clndisdb': [x.split(',') for x in
                          self.info['CLNDISDB'].split('|')]
             if 'CLNDISDB' in self.info else []})
        cln_data.update({'clndn': self.info['CLNDN'].split('|') if
                         'CLNDN' in self.info else []})
        cln_data.update({'clnvi': self.info['CLNVI'].split(',')
                        if 'CLNVI' in self.info else []})

        try:
            sequence = self.alt_alleles[0]
        except IndexError:
            sequence = self.ref_allele

        allele = ClinVarAllele(frequency=pref_freq, sequence=sequence,
                               **cln_data)

        # A few ClinVar variants are only reported as a combination with
        # other variants, and no single-variant effect is proposed. Skip these.
        if not cln_data['clnsig']:
            return []

        return [allele]



#!/usr/bin/python
#
"""Tools for parsing and matching VCF files"""

from .clinvar import ClinVarVCFLine
from .common import VCFLine
from .genome import GenomeVCFLine


def _next_line(filebuffer):
    try:
        next_line = filebuffer.readline()
    except AttributeError:
        next_line = filebuffer.next()
    try:
        next_line = next_line.decode('utf-8')
        return next_line
    except AttributeError:
        return next_line


def match_to_clinvar(genome_file, clin_file):
    """
    Match a genome VCF to variants in the ClinVar VCF file

    Acts as a generator, yielding tuples of:
    (ClinVarVCFLine, ClinVarAllele, zygosity)

    'zygosity' is a string and corresponds to the genome's zygosity for that
    ClinVarAllele. It can be either: 'Het' (heterozygous), 'Hom' (homozygous),
    or 'Hem' (hemizygous, e.g. X chromosome in XY individuals).
    """
    clin_curr_line = _next_line(clin_file)
    genome_curr_line = _next_line(genome_file)

    # Ignores all the lines that start with a hashtag
    while clin_curr_line.startswith('#'):
        clin_curr_line = _next_line(clin_file)
    while genome_curr_line.startswith('#'):
        genome_curr_line = _next_line(genome_file)

    # Advance through both files simultaneously to find matches
    while clin_curr_line and genome_curr_line:

        # Advance a file when positions aren't equal.
        clin_curr_pos = VCFLine.get_pos(clin_curr_line)
        genome_curr_pos = VCFLine.get_pos(genome_curr_line)
        try:
            if clin_curr_pos['chrom'] > genome_curr_pos['chrom']:
                genome_curr_line = _next_line(genome_file)
                continue
            elif clin_curr_pos['chrom'] < genome_curr_pos['chrom']:
                clin_curr_line = _next_line(clin_file)
                continue
            if clin_curr_pos['pos'] > genome_curr_pos['pos']:
                genome_curr_line = _next_line(genome_file)
                continue
            elif clin_curr_pos['pos'] < genome_curr_pos['pos']:
                clin_curr_line = _next_line(clin_file)
                continue
        except StopIteration:
            break

        # If we get here, start positions match.
        # Look for allele matching.
        genome_vcf_line = GenomeVCFLine(vcf_line=genome_curr_line,
                                        skip_info=True)
        # We can skip if genome has no allele information for this point.
        if not genome_vcf_line.genotype_allele_indexes:
            genome_curr_line = _next_line(genome_file)
            continue

        # Match only if ClinVar and Genome ref_alleles match.
        clinvar_vcf_line = ClinVarVCFLine(vcf_line=clin_curr_line)
        if not genome_vcf_line.ref_allele == clinvar_vcf_line.ref_allele:
            try:
                genome_curr_line = _next_line(genome_file)
                clin_curr_line = _next_line(clin_file)
                continue
            except StopIteration:
                break

        # Determine genome alleles and zygosity. Zygosity is assumed to be one
        # of: heterozygous, homozygous, or hemizygous.
        genotype_allele_indexes = genome_vcf_line.genotype_allele_indexes
        genome_alleles = [genome_vcf_line.alleles[x] for
                          x in genotype_allele_indexes]
        if len(genome_alleles) == 1:
            zygosity = 'Hem'
        elif len(genome_alleles) == 2:
            if genome_alleles[0].sequence == genome_alleles[1].sequence:
                zygosity = 'Hom'
                genome_alleles = [genome_alleles[0]]
            else:
                zygosity = 'Het'
        else:
            raise ValueError('This code only expects to work on genomes ' +
                             'with one or two alleles called at each ' +
                             'location. The following line violates this:' +
                             str(genome_vcf_line))

        # Look for matches to ClinVar alleles.
        for genome_allele in genome_alleles:
            for allele in clinvar_vcf_line.alleles:
                if genome_allele.sequence == allele.sequence:
                    # The 'records' attribute is specific to ClinVarAlleles.
                    if hasattr(allele, 'records'):
                        yield (genome_vcf_line, allele, zygosity)

        # Done matching, move on.
        try:
            genome_curr_line = _next_line(genome_file)
            clin_curr_line = _next_line(clin_file)
        except StopIteration:
            break



from setuptools import setup
from os import path

here = path.abspath(path.dirname(__file__))

setup(
    name='vcf2clinvar',
    version='0.1.5.0',
    description='Match a personal genome VCF datafile to ClinVar VCF',
    url='https://github.com/madprime/vcf2clinvar',
    author='Mad Price Ball',
    author_email='pgp-informatics@arvados.org',
    license='MIT',

    classifiers=[
        'Development Status :: 3 - Alpha',
    ],

    packages=['vcf2clinvar'],

    # Core dependencies should be listed here (will be installed by pip).
    install_requires=[],

    scripts=['clinvar_report.py'],

)
